@@ -147,6 +147,7 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
     @Override
     public void releaseResources() throws OXException {
         closeIMAPFolder();
+        closeOtherFolders();
     }
 
     /**
@@ -238,7 +239,6 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
     protected void resetIMAPFolder() {
         holdsMessages = -1;
         imapFolder = null;
-        closeOtherFolders();
     }
 
     /**
@@ -287,9 +287,6 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
         if (null == fullName) {
             throw MailExceptionCode.MISSING_FULLNAME.create();
         }
-        if (imapFolder == this.imapFolder) {
-            closeOtherFolders();
-        }
         final boolean isDefaultFolder = DEFAULT_FOLDER_ID.equals(fullName);
         final boolean isIdenticalFolder;
         if (isDefaultFolder) {
@@ -318,10 +315,14 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
                         return imapFolder;
                     }
                     /*
-                     * Folder is open, so close folder
+                     * Folder is open, but not appropriate. Add to opened folders for possible later use if not identical full name
                      */
                     try {
-                        imapFolder.close(false/*Folder.READ_WRITE == mode*/);
+                        if (isIdenticalFolder) {
+                            imapFolder.close(false/*Folder.READ_WRITE == mode*/);
+                        } else {
+                            addOpenedFolder(imapFolder);
+                        }
                     } finally {
                         if (imapFolder == this.imapFolder) {
                             resetIMAPFolder();
