@@ -51,7 +51,10 @@ package com.openexchange.imap.util;
 
 import java.util.Locale;
 import javax.mail.MessagingException;
+import javax.mail.Store;
+import com.openexchange.java.StringAllocator;
 import com.sun.mail.iap.Response;
+import com.sun.mail.imap.IMAPFolder;
 
 /**
  * {@link ImapUtility} - IMAP utility class.
@@ -67,6 +70,57 @@ public final class ImapUtility {
         super();
     }
 
+    /**
+     * Appends command information to given information string.
+     *
+     * @param info The information
+     * @param imapFolder The optional IMAP folder
+     * @return The command with optional information appended
+     */
+    public static String appendCommandInfo(final String info, final IMAPFolder imapFolder) {
+        if (null == imapFolder) {
+            return info;
+        }
+        final StringAllocator sb = new StringAllocator(info);
+        sb.append(" (folder=\"").append(imapFolder.getFullName()).append('"');
+        final Store store = imapFolder.getStore();
+        if (null != store) {
+            sb.append(", store=\"").append(store.toString()).append('"');
+        }
+        sb.append(')');
+        return sb.toString();
+    }
+
+    /**
+     * Appends command information to given information string.
+     *
+     * @param info The information
+     * @param fullName The optional full name of associated folder
+     * @param store The optional description of connected IMAP store
+     * @return The command with optional information appended
+     */
+    public static String appendCommandInfo(final String info, final String fullName, final String store) {
+        final StringAllocator sb = new StringAllocator(info);
+        boolean parenthesis = true;
+        if (!isEmpty(fullName)) {
+            sb.append(" (folder=\"").append(fullName).append('"');
+            parenthesis = false;
+        }
+        if (!isEmpty(store)) {
+            if (parenthesis) {
+                sb.append(" (");
+                parenthesis = false;
+            } else {
+                sb.append(", ");
+            }
+            sb.append("store=\"").append(store).append('"');
+        }
+        if (!parenthesis) {
+            sb.append(')');
+        }
+        return sb.toString();
+    }
+
     /**
      * Checks if given <code>MessagingException</code> indicates "Invalid messageset" or "Invalid uidset" error.
      *
@@ -122,4 +176,16 @@ public final class ImapUtility {
         return sResponse.indexOf("invalid messageset") >= 0 || sResponse.indexOf("invalid uidset") >= 0;
     }
 
+    private static boolean isEmpty(final String string) {
+        if (null == string) {
+            return true;
+        }
+        final int len = string.length();
+        boolean isWhitespace = true;
+        for (int i = 0; isWhitespace && i < len; i++) {
+            isWhitespace = Character.isWhitespace(string.charAt(i));
+        }
+        return isWhitespace;
+    }
+
 }
